@@ -1,20 +1,16 @@
 /* try all types from server */
 
-#undef NDEBUG
-#include <config.h>
-
-#include <stdio.h>
-#include <ctpublic.h>
 #include "common.h"
+
 #include <ctlib.h>
-#include <assert.h>
+
 #define TDS_DONT_DEFINE_DEFAULT_FUNCTIONS
 #include "../../tds/unittests/common.h"
 #include <freetds/tds.h>
 
 static CS_CONTEXT *ctx = NULL;
 
-static void test_type(TDSSOCKET *tds, TDSCOLUMN *col)
+static void test_type(TDSSOCKET *tds TDS_UNUSED, TDSCOLUMN *col)
 {
 	TDSRESULTINFO *resinfo, *bindinfo;
 	TDSCOLUMN *oldcol, *bindcol;
@@ -66,14 +62,14 @@ static void test_type(TDSSOCKET *tds, TDSCOLUMN *col)
 }
 
 int
-main(int argc, char **argv)
+main(void)
 {
 	TDSCONTEXT *tds_ctx;
 	TDSSOCKET *tds;
-	CS_RETCODE ret;
 
-	ret = cs_ctx_alloc(CS_VERSION_100, &ctx);
-	assert(ret == CS_SUCCEED);
+	tdsdump_topen(tds_dir_getenv(TDS_DIR("TDSDUMP")));
+
+	check_call(cs_ctx_alloc, (CS_VERSION_100, &ctx));
 
 	tds_ctx = tds_alloc_context(NULL);
 	assert(tds_ctx);
